sample_test_fail_first_setup_20141211_223839

### sample_config1 : test1

Result | Function execution time | Total execution time
--- | --- | ---
Passed | 9.53674316406e-07 sec | 2.40802764893e-05 sec

Naarad report

### Metrics

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
sample-perf | latency | p99 lt 300.0 | None
sample-perf | latency | p50 lt 250.0 | None
sample-perf | latency | mean lt 125.0 | None
sample-perf | qps | mean lt 10.0 | None